import React, { useEffect, useState } from 'react'
import { Form, Space, TreeSelect, Button, Input, Modal, message } from 'antd'
import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons'
import styles from './index.less'
import { ReloadTableFields, QueryFields } from '../../../../../apis/process'
import Drag from '../../../../components/Drag'

const { TreeNode } = TreeSelect

const DeviceFieldshine = (props) => {

  const { addons, onChange, value } = props
  const { $id, accountName, tableNameParent } = addons.formData

  const [form] = Form.useForm()
  const [visible, setVisible] = useState(false)
  const [fromField, setFromField] = useState([])
  const [toField, setToField] = useState([])

  const onOk = () => {
    form
      .validateFields()
      .then((values) => {
        const { field } = form.getFieldsValue()
        if (field.length !== 1) {
          addons.setValue('isMultiple', false)
        }
        onChange(field)
        setVisible(false)
      })
      .catch((info) => {
        console.log('Validate Failed:', info)
      })
  }

  const inputClick = async () => {
    const { code, data } = await ReloadTableFields({ tableName: tableNameParent })
    if (code === 0) {
      setToField(data.root)
    }
    let field = value.length ? value : [{ fromField: 'GIS编码', toField: 'GIS编码' }, { fromField: 'GIS图层', toField: 'GIS图层' }]
    form.setFieldsValue({ field })
    setVisible(true)
  }

  return (
    <div className={styles.fieldshine}>
      <Input
        value={value && value.length ? JSON.stringify(value) : null}
        onClick={inputClick}
      />
      <Drag
        getContainer={false}
        width='450px'
        title='字段映射'
        visible={visible}
        onCancel={() => setVisible(false)}
        onOk={onOk}
      >
        <Form name="dynamic_form_nest_item" form={form} autoComplete="off">
          <Form.List name="field">
            {(value, { add, remove }) => (
              <>
                {value.map(({ key, name, ...restField }, index) => (
                  <Space
                    key={key}
                    // style={{
                    //   display: 'flex',
                    //   marginBottom: '5px                                           ',
                    //   justifyContent: 'center',
                    //   position: 'relative',
                    //   left: index === 0 ? '-11px' : '',
                    // }}
                    align="baseline"
                  >
                    <Form.Item
                      {...restField}
                      name={[name, 'fromField']}
                      rules={[
                        {
                          required: true,
                          message: '来源字段必填',
                        }
                      ]}
                    >
                      <TreeSelect
                        showSearch
                        style={{ width: '180px' }}
                        dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                        placeholder="请选择字段名 "
                        allowClear
                        treeDefaultExpandAll
                        showCheckedStrategy
                      >
                        <TreeNode value={accountName} title={accountName} disabled>
                          {fromField.map(s => <TreeNode value={s} title={s} key={s} />)}
                        </TreeNode>
                      </TreeSelect>
                    </Form.Item>
                    <div className={styles.centerImg}></div>
                    <Form.Item
                      {...restField}
                      name={[name, 'toField']}
                      rules={[
                        {
                          required: true,
                          message: '目标字段必填',
                        },
                        {
                          validator: (rules, value, callback) => {
                            const { field } = form.getFieldsValue()
                            let toFields = Array.from(new Set([...field.map(v => v.toField)]))
                            if (toFields.length !== field.length) {
                              return Promise.reject('目标字段不能重复！')
                            }
                            return Promise.resolve()
                          }
                        }
                      ]}
                    >
                      <TreeSelect
                        showSearch
                        style={{ width: '180px' }}
                        dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                        placeholder="请选择字段名 "
                        allowClear
                        treeDefaultExpandAll
                        showCheckedStrategy
                      >
                        <TreeNode value={tableNameParent} title={tableNameParent} disabled>
                          {toField.map(s => <TreeNode value={s.name} title={s.name} key={s.name} />)}
                        </TreeNode>
                      </TreeSelect>
                    </Form.Item>
                    {/* {index !== 0 ? <MinusCircleOutlined onClick={() => remove(name)} /> : null} */}
                  </Space>
                ))}
                {/* <Form.Item style={{ padding: '0 10px' }}>
                  <Button type="dashed" onClick={() => add()} block icon={<PlusOutlined />}>
                    添加映射
                  </Button>
                </Form.Item> */}
              </>
            )}
          </Form.List>
        </Form>
      </Drag>
    </div>
  )

}

export default DeviceFieldshine